% Randomly shift nodes in a three-dimensional block.
%
% function fens = block_random_shift(fens, amplitude, options)
%
% The locations of the nodes are shifted randomly, but so that nodes on the
% boundary remain on the boundary.
function fens = block_random_shift(fens, amplitude, options)
    Dimension =length(get(fens(1),'xyz'));
    if length(amplitude)==1
        amplitude =zeros(1,Dimension)+ amplitude;
    end
    xyz =zeros(length(fens),Dimension);
    for j=1:length(fens)
        xyz(j, :)=get(fens(j),'xyz');
    end
    xyz0 = xyz;
    
    minxyz =[];
    maxxyz =[];
    for j=1:Dimension
        minxyz(j) =min(xyz(:,j));
        maxxyz(j) =max(xyz(:,j));
    end
    
    link = [];
    linktol = [];
    if isfield(options,'link')
        link = options.link;
        if isfield(options,'linktol')
            linktol = options.linktol;
        else
            linktol = min([(maxxyz-minxyz)/1e7;amplitude/length(fens)]);
        end
    end
    
    for j=1:Dimension
        if (~isempty(link) && (~link(j)))
            for q= 1:length(fens)
                box = [];
                for k=1:Dimension
                    if (~link(k)),box = [box, xyz0(q,k), xyz0(q,k)];
                    else,         box = [box, minxyz(k), maxxyz(k)];                    end
                end
                linkednl=fenode_select (fens,struct ('box',box,'inflate',linktol(j)));
                xyz(linkednl,j)=xyz0(linkednl,j) + amplitude(j)*(2*rand(1)-1);
            end
        else
            xyz(:,j)=xyz0(:,j) + amplitude(j)* (2*rand(length(fens),1)-1);
        end
    end
    Tol = min([norm(maxxyz-minxyz)/1e7,min(amplitude)/length(fens)]);
    
    %     make sure the nodes do not leave the box
    for j=1:Dimension
        box = [];
        for k=1:Dimension
            if j==k
                box = [box, minxyz(k), minxyz(k)];
            else
                box = [box, minxyz(k), maxxyz(k)];
            end
        end
        minxnl=fenode_select (fens,struct ('box',box,'inflate',Tol));
        box = [];
        for k=1:Dimension
            if j==k
                box = [box, maxxyz(k), maxxyz(k)];
            else
                box = [box, minxyz(k), maxxyz(k)];
            end
        end
        maxxnl=fenode_select (fens,struct ('box',box,'inflate',Tol));
        xyz(minxnl,j) =minxyz(j);
        xyz(maxxnl,j) =maxxyz(j);
    end
    
    %     now set the new coordinates
    for j=1:length(fens)
        fens(j)=set(fens(j),'xyz', xyz(j, :));
    end    
end
  
